package com.miaxis.app.controller.customer;

import com.miaxis.collection.service.ICollectionInfoService;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.SecurityUtils;
import com.miaxis.customer.domain.CustomerInfo;
import com.miaxis.customer.service.ICustomerInfoService;
import com.miaxis.customer.vo.ExhibitionCustomerInfoVo;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 【小程序-客户信息】Controller
 *
 * @author miaxis
 * @date 2021-03-10
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.STUDENT_PREFIX+"/applet/customer")
@Api(tags = {"【小程序-客户信息】"})
public class AppletCustomerInfoController extends BaseController {

    private final ICustomerInfoService customerInfoService;


    /**
     * 查询商家列表
     */
    @GetMapping(value = "/getCustomerListByProductId/{id}")
    @ApiOperation("查询商家列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<ExhibitionCustomerInfoVo> getCustomerListByProductId(
            @ApiParam(name = "id", value = "品类id (0:精选列表)", required = true)
            @PathVariable("id") Long id
    ) {
        startPage();
        //获取当前用户
        UserInfo userInfo = SecurityUtils.getLoginUser().getStudent();
        List<ExhibitionCustomerInfoVo> list = customerInfoService.getCustomerListByProductId(id,userInfo.getId());
        return toResponsePageInfo(list);
    }


}
